# This script creates a directory, "data", then opens all files in the directory it is runned from
# If the file is a .mp4 video it opens it and reads it frame by frame
# Each frame is then saved to a .jpg file in the new directory with a unique name
# Built using Python 3.2.7 with openCV, ffmpeg installed
# Run in the directory containing the video files
# Usage: python imext.py

# Importing all necessary libraries 
import cv2 
import os 
  
try: 
		  
	# creating a folder named data 
	if not os.path.exists('data'): 
		os.makedirs('data') 
	  
	# if not created then raise error 
except OSError: 
	print ('Error: Creating directory of data') 

#For each file in the current directory
for file in os.listdir(os.getcwd()):
	
	# Only run if file is video
	if file.endswith('.mp4'):
	
		# Read the video from current directory
		fi = cv2.VideoCapture(file)
		
		# Check if video opened successfully
		if (fi.isOpened()== False): 
			print("Error opening video stream or file")
		
		# Set frame counter
		currentframe = 0
		
		# Read while video is open
		while(fi.isOpened()):
			# reading from frame 
			ret, frame = fi.read() 
		
			# if frames are still left, continue creating images 
			if (ret): 
				
				# Depending on which folder it's runned from
				name = './data/' + file[:-4] + '_settefisk_' + str(currentframe) + '.jpg'
				#name = './data/' + file[:-4] + '_villfisk_' + str(currentframe) + '.jpg'
				print ('Creating...' + name) 
		  
				# writing the extracted images 
				cv2.imwrite(name, frame) 
		  
				# increasing counter so that it will 
				# show how many frames are created 
				currentframe += 1
			
			# break when out of frames
			else:
				break
	  
# Release all space and windows once done 
fi.release() 
cv2.destroyAllWindows() 
	
